@@ -20,22 +20,63 @@
 
 package App::MtAws::Exceptions;
 
-our $VERSION = '1.000';
+our $VERSION = '1.000_1';
 
 use strict;
 use warnings;
 use utf8;
+use Encode;
+use constant BINARY_ENCODING => "MT_BINARY";
+use App::MtAws::Utils;
+
 use Carp;
+use I18N::Langinfo;
 
 require Exporter;
 use base qw/Exporter/;
 
 
-our @EXPORT = qw/exception get_exception is_exception exception_message dump_error/;
+our @EXPORT = qw/exception get_exception is_exception exception_message dump_error get_errno/;
+
+our $_errno_encoding = undef;
+
+sub get_raw_errno { @_ ? shift : $! } # testable
+sub get_errno
+{
+	local $@;
+	my $err = &get_raw_errno; # TODO: we actually use it only with argument!
+	local $!;
+
+	# some code in this scope copied from Encode::Locale
+	# http://search.cpan.org/perldoc?Encode%3A%3ALocale
+	# by Gisle Aas <gisle@aas.no>.
+	$_errno_encoding ||= eval {
+		my $enc = I18N::Langinfo::langinfo(I18N::Langinfo::CODESET());
+		# copy-paste workaround from Encode::Locale
+		# https://rt.cpan.org/Ticket/Display.html?id=66373
+		$enc = "hp-roman8" if $^O eq "hpux" && $enc eq "roman8";
+
+		defined (find_encoding($enc)) ? $enc : undef;
+	} || BINARY_ENCODING();
+
+	my $res;
+	if ($_errno_encoding eq BINARY_ENCODING) {
+		$res = hex_dump_string($err);
+	} else {
+		eval {
+			$res = decode($_errno_encoding, $err);
+			1;
+		} or do {
+			$res = hex_dump_string($err);
+		}
+	}
+	$res;
+}
 
 # Does not work with directory names
 
-# exception [$previous] { $msg | $code => $msg } @vars
+# exception [$previous] { $msg | $code => $msg } name1 => value1, name2 => value2 ...
+# exception [$previous] { $msg | $code => $msg } name1 => value1, 'ERRNO', name2 => value2 ...
 sub exception
 {
 	my %data;
@@ -43,8 +84,17 @@ sub exception
 	if (scalar @_ == 1) {
 		$data{message} = shift;
 	} else {
-		(@data{qw/code message/}, my %others) = @_;
-		%data = (%data, %others);
+		@data{qw/code message/} = (shift, shift);
+		while (@_) {
+			my $key = shift;
+			if ($key eq 'ERRNO') {
+				confess "ERRNO already used" if exists $data{'errno'};
+				$data{'errno'} = get_errno($!);
+				$data{'errno_code'} = $!+0; # numify
+			} else {
+				$data{$key} = shift or confess "Malformed exception"
+			}
+		}
 	}
 	return { 'MTEXCEPTION' => 1, %data };
 }
@@ -92,7 +142,7 @@ sub exception_message
 			defined($data{$match}) ? $data{$match} : ':NULL:';
 		}
 	};
-	
+
 	$spec =~ s{%([\w\s]+)%} {$rep->($1)}ge if %data; # in new perl versions \w also means unicode chars..
 	$spec;
 }
